;;;; uuid-ossp-eggdoc.scm

(use eggdoc)

(define license
"Copyright (c) 2006, Kon Lovett.  All rights reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the Software),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED ASIS, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.")

(define doc `(
  (eggdoc:begin
    (name "uuid-ossp")
    (description (p "OSSP UUID"))
    (author (url "mailto:klovett@pacbell.net" "Kon Lovett"))
    (history
      (version "1.22" "Ported to Chicken 4")
      (version "1.21" "Note about OSSP UUID Release >= 1.3.0 requirement [Thanks to arto]")
      (version "1.2" "Exports")
      (version "1.1" "Some build, internals & documentation changes [Thanks to Reed Sheridan]")
      (version "1.0" "Initial release"))
    (requires lolevel)
    (usage)
    (download "uuid-ossp.egg")

    (documentation

      (p "Provides access to the "
      (url "http://www.ossp.org/pkg/lib/uuid" "OSSP UUID Library") ". "
      "This document does not supplant the OSSP UUID Library documentation.")

      (p "The OSSP UUID Library is not included in this distribution. The "
      "library source is available at the above URL. See the " (b "Issues") " "
      "section below for more information.")

      (subsection "Pre-defined Namespaces"

        (symbol-table
          (describe "\"nil\"" (p "00000000-0000-0000-0000-000000000000"))
          (describe "\"ns:DNS\"" (p "6ba7b810-9dad-11d1-80b4-00c04fd430c8"))
          (describe "\"ns:URL\"" (p "6ba7b811-9dad-11d1-80b4-00c04fd430c8"))
          (describe "\"ns:OID\"" (p "6ba7b812-9dad-11d1-80b4-00c04fd430c8"))
          (describe "\"ns:X500\"" (p "6ba7b814-9dad-11d1-80b4-00c04fd430c8"))
        )

        (p "")
      )

      (subsection "UUID Variants"

        (symbol-table
          (describe V1 (p "DCE 1.1 variant UUID of version 1"))
          (describe V1-MC (p "DCE 1.1 variant UUID of version 1 with random MAC address"))
          (describe V3 (p "DCE 1.1 variant UUID of version 3"))
          (describe V4 (p "DCE 1.1 variant UUID of version 4"))
          (describe V5 (p "DCE 1.1 variant UUID of version 5"))
        )

        (p "")
      )

      (subsection "Comparison Procedures"

        (procedure "(uuid? UUID)"
          (p "Is " (tt "UUID") " a uuid?"))

        (procedure "(uuid-nil? UUID)"
          (p "Is " (tt "UUID") " the \"nil\" uuid?"))

        (procedure "(uuid= UUID1 UUID2)"
          (p "Are " (tt "UUID1") " and " (tt "UUID2") " equal?"))

        (procedure "(uuid<> UUID1 UUID2)"
          (p "Are " (tt "UUID1") " and " (tt "UUID2") " not equal?"))

        (procedure "(uuid< UUID1 UUID2)"
          (p "Does " (tt "UUID1") " order below " (tt "UUID2") "?"))

        (procedure "(uuid> UUID1 UUID2)"
          (p "Does " (tt "UUID1") " order above " (tt "UUID2") "?"))

        (procedure "(uuid<= UUID1 UUID2)"
          (p "Does " (tt "UUID1") " order below or the same as " (tt "UUID2") "?"))

        (procedure "(uuid>= UUID1 UUID2)"
          (p "Does " (tt "UUID1") " order above or the same as " (tt "UUID2") "?"))
      )

      (subsection "Creation Procedures"

        (procedure "(uuid-clone UUID)"
          (p "Returns a copy of the " (tt "UUID") "."))

        (procedure "(uuid-load NAMESPACE)"
          (p "Returns a uuid for the " (tt "NAMESPACE") "."))

        (procedure "(make-uuid [VARIANT [NAMESPACE NAME]])"
          (p "Returns a uuid " (tt "VARIANT") ", or the nil uuid when "
          "missing. The " (tt "NAMESPACE") " and " (tt "NAME") " are "
          "required for V3 and V5."))

        (procedure "(uuid-import STRING)"
          (p "Returns a uuid from the external " (tt "STRING") " representation."))

        (procedure "(uuid-import-binary BINARY-STRING)"
          (p "Returns a uuid from the external " (tt "BINARY-STRING") " representation."))
      )

      (subsection "Export Procedures"

        (procedure "(uuid-export UUID)"
          (p "Returns the external string representation of " (tt "UUID") "."))

        (procedure "(uuid-export-binary UUID)"
          (p "Returns the external binary-string representation of " (tt "UUID") "."))

        (procedure "(uuid-export-text UUID)"
          (p "Returns the external text representation of " (tt "UUID") "."))
      )

      (subsection "Auxillary Procedures"

        (procedure "(uuid-version)"
          (p "Returns OSSP UUID Library version as an unsigned-long."))
      )

      (subsection "Errors"

        (p "Errors generated by the OSSP UUID Library are signalled "
        "using a condition of " (code "(exn uuid)") " , with properties "
        (code "message") ", the error message, and " (code "code") ", "
        "the error code.")

        (p "Argument errors are signalled using " (code "error") ".")
      )
    )

    (section "Issues"

      (p "Requires at least release 1.3.0 of the OSSP UUID Library.")

      (p "The use of the \"uuid\" prefix/name by the OSSP UUID Library "
      "is problematic. A generic name often with an existing meaning.")

      (p "Reed Sheridan has pointed out that the Debian system renames "
      "the library, as an existing library of the same name already "
      "exists. For example, " (code "uuid.h") " is " (code "ossp/uuid.h") ".")

      (p "Without the use of a build system which can deal with platform "
      "specific conditions installation of this egg might require manual "
      "intervention. The file \"uuid-ossp-fix.c\" has the references to the include file.")
    )

    (section "License" (pre ,license))
  )
))

(eggdoc->html doc)
